@@ -1,6 +1,6 @@
-from camera_simulator_alg.base_processor import BaseProcessor
-from camera_simulator_alg.lens import Lens
-import camera_simulator_alg.contants as ct
+from .base_processor import BaseProcessor
+from .lens import Lens
+from .contants import HEIGHT_SIZE, WIDTH_SIZE
 import numpy as np 
 
 class Sensor(BaseProcessor):
@@ -19,7 +19,7 @@ class Sensor(BaseProcessor):
         super().__init__(enable)
         self._gain = gain
 
-    @Lens(enable = True, height = ct.HEIGHT_SIZE, width = ct.WIDTH_SIZE).decorator
+    @Lens(enable = True, height = HEIGHT_SIZE, width = WIDTH_SIZE).decorator
     def process(self, image: np.array) -> np.array:
         """This function first validate that the shape of the input numpy data 
            matches de Lens height and width properties and then returns the input 
